--- old/usr/src/uts/common/vm/vm_seg.c	2015-05-08 18:03:58.607371670 -0400
+++ new/usr/src/uts/common/vm/vm_seg.c	2015-05-08 18:03:58.614726306 -0400
@@ -1862,3 +1862,195 @@
 {
 	return (ENOTSUP);
 }
+
+/*
+ * segop wrappers
+ */
+int
+segop_dup(struct seg *seg, struct seg *new)
+{
+	VERIFY3P(seg->s_ops->dup, !=, NULL);
+
+	return (seg->s_ops->dup(seg, new));
+}
+
+int
+segop_unmap(struct seg *seg, caddr_t addr, size_t len)
+{
+	VERIFY3P(seg->s_ops->unmap, !=, NULL);
+
+	return (seg->s_ops->unmap(seg, addr, len));
+}
+
+void
+segop_free(struct seg *seg)
+{
+	VERIFY3P(seg->s_ops->free, !=, NULL);
+
+	seg->s_ops->free(seg);
+}
+
+faultcode_t
+segop_fault(struct hat *hat, struct seg *seg, caddr_t addr, size_t len,
+    enum fault_type type, enum seg_rw rw)
+{
+	VERIFY3P(seg->s_ops->fault, !=, NULL);
+
+	return (seg->s_ops->fault(hat, seg, addr, len, type, rw));
+}
+
+faultcode_t
+segop_faulta(struct seg *seg, caddr_t addr)
+{
+	VERIFY3P(seg->s_ops->faulta, !=, NULL);
+
+	return (seg->s_ops->faulta(seg, addr));
+}
+
+int
+segop_setprot(struct seg *seg, caddr_t addr, size_t len, uint_t prot)
+{
+	VERIFY3P(seg->s_ops->setprot, !=, NULL);
+
+	return (seg->s_ops->setprot(seg, addr, len, prot));
+}
+
+int
+segop_checkprot(struct seg *seg, caddr_t addr, size_t len, uint_t prot)
+{
+	VERIFY3P(seg->s_ops->checkprot, !=, NULL);
+
+	return (seg->s_ops->checkprot(seg, addr, len, prot));
+}
+
+int
+segop_kluster(struct seg *seg, caddr_t addr, ssize_t d)
+{
+	VERIFY3P(seg->s_ops->kluster, !=, NULL);
+
+	return (seg->s_ops->kluster(seg, addr, d));
+}
+
+int
+segop_sync(struct seg *seg, caddr_t addr, size_t len, int atr, uint_t f)
+{
+	VERIFY3P(seg->s_ops->sync, !=, NULL);
+
+	return (seg->s_ops->sync(seg, addr, len, atr, f));
+}
+
+size_t
+segop_incore(struct seg *seg, caddr_t addr, size_t len, char *v)
+{
+	VERIFY3P(seg->s_ops->incore, !=, NULL);
+
+	return (seg->s_ops->incore(seg, addr, len, v));
+}
+
+int
+segop_lockop(struct seg *seg, caddr_t addr, size_t len, int atr, int op,
+    ulong_t *b, size_t p)
+{
+	VERIFY3P(seg->s_ops->lockop, !=, NULL);
+
+	return (seg->s_ops->lockop(seg, addr, len, atr, op, b, p));
+}
+
+int
+segop_getprot(struct seg *seg, caddr_t addr, size_t len, uint_t *p)
+{
+	VERIFY3P(seg->s_ops->getprot, !=, NULL);
+
+	return (seg->s_ops->getprot(seg, addr, len, p));
+}
+
+u_offset_t
+segop_getoffset(struct seg *seg, caddr_t addr)
+{
+	VERIFY3P(seg->s_ops->getoffset, !=, NULL);
+
+	return (seg->s_ops->getoffset(seg, addr));
+}
+
+int
+segop_gettype(struct seg *seg, caddr_t addr)
+{
+	VERIFY3P(seg->s_ops->gettype, !=, NULL);
+
+	return (seg->s_ops->gettype(seg, addr));
+}
+
+int
+segop_getvp(struct seg *seg, caddr_t addr, struct vnode **vpp)
+{
+	VERIFY3P(seg->s_ops->getvp, !=, NULL);
+
+	return (seg->s_ops->getvp(seg, addr, vpp));
+}
+
+int
+segop_advise(struct seg *seg, caddr_t addr, size_t len, uint_t b)
+{
+	VERIFY3P(seg->s_ops->advise, !=, NULL);
+
+	return (seg->s_ops->advise(seg, addr, len, b));
+}
+
+void
+segop_dump(struct seg *seg)
+{
+	VERIFY3P(seg->s_ops->dump, !=, NULL);
+
+	seg->s_ops->dump(seg);
+}
+
+int
+segop_pagelock(struct seg *seg, caddr_t addr, size_t len, struct page ***page,
+    enum lock_type type, enum seg_rw rw)
+{
+	VERIFY3P(seg->s_ops->pagelock, !=, NULL);
+
+	return (seg->s_ops->pagelock(seg, addr, len, page, type, rw));
+}
+
+int
+segop_setpagesize(struct seg *seg, caddr_t addr, size_t len, uint_t szc)
+{
+	VERIFY3P(seg->s_ops->setpagesize, !=, NULL);
+
+	return (seg->s_ops->setpagesize(seg, addr, len, szc));
+}
+
+int
+segop_getmemid(struct seg *seg, caddr_t addr, memid_t *mp)
+{
+	VERIFY3P(seg->s_ops->getmemid, !=, NULL);
+
+	return (seg->s_ops->getmemid(seg, addr, mp));
+}
+
+struct lgrp_mem_policy_info *
+segop_getpolicy(struct seg *seg, caddr_t addr)
+{
+	if (seg->s_ops->getpolicy == NULL)
+		return (NULL);
+
+	return (seg->s_ops->getpolicy(seg, addr));
+}
+
+int
+segop_capable(struct seg *seg, segcapability_t cap)
+{
+	VERIFY3P(seg->s_ops->capable, !=, NULL);
+
+	return (seg->s_ops->capable(seg, cap));
+}
+
+int
+segop_inherit(struct seg *seg, caddr_t addr, size_t len, uint_t op)
+{
+	if (seg->s_ops->inherit == NULL)
+		return (ENOTSUP);
+
+	return (seg->s_ops->inherit(seg, addr, len, op));
+}
